PyFemtet is the extension package for Femtet with Python.

- Femtet Website: https://www.muratasoftware.com/
- Documentation: https://pyfemtet.github.io/pyfemtet/
- Source code: https://github.com/pyfemtet/pyfemtet
- Bug reports: https://github.com/pyfemtet/pyfemtet/issues


It provides:

- single and multi objective parameter optimization
- tools for connect Femtet and Python by pid
